[![HitCount](http://hits.dwyl.io/aayushuppal/sappgen.svg)](https://github.com/aayushuppal/sappgen)
[![GitHub contributors](https://img.shields.io/github/contributors/aayushuppal/sappgen.svg)](https://github.com/aayushuppal/sappgen/graphs/contributors)
[![Version](https://img.shields.io/pypi/v/sappgen.svg)](https://pypi.python.org/pypi/sappgen)
[![License](https://img.shields.io/pypi/l/sappgen.svg)](https://pypi.python.org/pypi/sappgen)
[![Build Status](https://travis-ci.org/aayushuppal/sappgen.svg?branch=master)](https://travis-ci.org/aayushuppal/sappgen)
[![Downloads](https://img.shields.io/pypi/dm/sappgen.svg)](https://pypi.python.org/pypi/sappgen)

# SAPPGEN

Simple App Generator for Python - Command line utility

Python `3.7`

## Installation

- Install from [PyPi](https://pypi.org/project/sappgen)

`pip install sappgen`

## Usage:

    $ sappgen [options] <project_name> <app_name>
    $ sappgen proj app

## Available options are:

    -h, --help         Show help

## Default App Template: Template 1 - App structure

    proj1
    ├── app1
    │   └── util
    │   │   ├── __init__.py
    │   │   └── log_util.py
    │   │── __init__.py
    │   └── app.py
    ├── config.ini
    ├── main.py
    │
    ├── tests
    |   └── test_app1.py
    │
    ├── Makefile
    ├── README.md
    └── requirements-dev.txt

## Contact

- https://aayushuppal.github.io

## Links

- https://pypi.org/project/sappgen
- https://github.com/aayushuppal/sappgen
